@@ -73,12 +73,16 @@ class ClientLoop(object):
         j = self.read_serve_list()
         client_d = self.read_client_md5_value()
         # 遍历所有的名字,检查需不需要下载,然后下载就好了
+        count = 0
         for name, md5_value in j.items():
             if name not in client_d:
+                count +=1
                 self.download(name, client_d)
                 continue
             if client_d[name] != md5_value:
+                count +=1
                 self.download(name, client_d)
+        click.echo("download file count: {}".format(count))
         self.read_client_md5_value()
     
     def download(self, name,d):
